==> pdf-model-arlington-1.27.18-sources.jar: org/verapdf/model/alayer/AGTS_ProcStepsGroup.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015-2024, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AGTS_ProcStepsGroup extends AObject {
	

	/**
	*/
	public Boolean getcontainsGTS_ProcStepsGroup();

	/**
	*/
	public String getGTS_ProcStepsGroupType();

	/**
	*/
	public Boolean getGTS_ProcStepsGroupHasTypeName();

	/**
	*/
	public String getGTS_ProcStepsGroupNameValue();

	/**
	*/
	public Boolean getcontainsGTS_ProcStepsType();

	/**
	*/
	public String getGTS_ProcStepsTypeType();

	/**
	*/
	public Boolean getGTS_ProcStepsTypeHasTypeName();

	/**
	*/
	public String getGTS_ProcStepsTypeNameValue();

	/**
	*/
	public Boolean getcontainsGWG__ProcStepsColorants();

	/**
	*/
	public String getGWG__ProcStepsColorantsType();

	/**
	*/
	public Boolean getGWG__ProcStepsColorantsHasTypeName();
}

==> pdf-model-arlington-1.29.12-sources.jar: org/verapdf/model/alayer/AGTS_ProcStepsGroup.java <==
/**
 * This file is part of VeraPDF Validation Model API for Arlington PDF Model, a module of the veraPDF project.
 * Copyright (c) 2015-2025, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * VeraPDF Validation Model API for Arlington PDF Model is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with VeraPDF Validation Model API for Arlington PDF Model as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * VeraPDF Validation Model API for Arlington PDF Model as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AGTS_ProcStepsGroup extends AObject {
	

	/**
	*/
	public Boolean getcontainsGTS_ProcStepsColorants();

	/**
	*/
	public String getGTS_ProcStepsColorantsType();

	/**
	*/
	public Boolean getGTS_ProcStepsColorantsHasTypeName();

	/**
	*/
	public Boolean getcontainsGTS_ProcStepsGroup();

	/**
	*/
	public String getGTS_ProcStepsGroupType();

	/**
	*/
	public Boolean getGTS_ProcStepsGroupHasTypeName();

	/**
	*/
	public String getGTS_ProcStepsGroupNameValue();

	/**
	*/
	public Boolean getcontainsGTS_ProcStepsType();

	/**
	*/
	public String getGTS_ProcStepsTypeType();

	/**
	*/
	public Boolean getGTS_ProcStepsTypeHasTypeName();

	/**
	*/
	public String getGTS_ProcStepsTypeNameValue();
}
